@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 import argparse
 # local files
-from mkdocs_placeholder_plugin.utils import load_placeholder_data
+from mkdocs_placeholder_plugin.placeholder_data import load_placeholder_data
 from mkdocs_placeholder_plugin.static_replacer import StaticReplacer
 
 
