@@ -17,10 +17,12 @@ PlaceholderPlugin.prepare_textbox_field = (placeholder_name, input_element) => {
         input_element.style.cursor = "not-allowed";
     } else {
         if (data.validators == undefined) {
+            // No validators -> no need to handle exception when validation fails
             input_element.addEventListener("keypress", e => {
                 if (e.key === "Enter") {
                     debug("Textbox change confirmed with Enter key for ", placeholder_name, "- new value:", input_element.checked);
                     PlaceholderPlugin.store_textbox_state(placeholder_name, input_element.value);
+                    PlaceholderPlugin.on_placeholder_change();
                 }
             });
             // Return an action to perform when the apply button is clicked
@@ -29,7 +31,7 @@ PlaceholderPlugin.prepare_textbox_field = (placeholder_name, input_element) => {
                 return true;
             }
         } else {
-            debug(`Has validator: ${placeholder_name}`);
+            // debug(`Has validator: ${placeholder_name}`);
             // Check if initial value is valid
             PlaceholderPlugin.validate_input_field(input_element, placeholder_name, false);
 
@@ -39,8 +41,8 @@ PlaceholderPlugin.prepare_textbox_field = (placeholder_name, input_element) => {
             });
             input_element.addEventListener("keypress", e => {
                 if (e.key === "Enter") {
-                    debug("Textbox change confirmed with Enter key for ", placeholder_name, "- new value:", input_element.checked);
-                    PlaceholderPlugin.validate_input_field(input_element, placeholder_name, true);
+                    debug("Textbox change confirmed with Enter key for ", placeholder_name, "- new value:", input_element.value);
+                    PlaceholderPlugin.validate_input_field(input_element, placeholder_name, true, reload_on_apply=true);
                 }
             });
             // Return an action to perform when the apply button is clicked
